==> commons-configuration2_2.1.1.orig.tar.xz: commons-configuration2-2.1.1-src/src/test/java/org/apache/commons/configuration2/event/TestEventType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.configuration2.event;

import static org.junit.Assert.assertEquals;

import org.junit.Before;
import org.junit.Test;

/**
 * Test class for {@code EventType}.
 *
 * @version $Id: TestEventType.java 1624601 2014-09-12 18:04:36Z oheger $
 */
public class TestEventType
{
    /** The event type to be tested. */
    private EventType<Event> eventType;

    @Before
    public void setUp() throws Exception
    {
        eventType = new EventType<Event>(null, "TEST");
    }

    /**
     * Tests the string representation.
     */
    @Test
    public void testToString()
    {
        String s = eventType.toString();
        assertEquals("Wrong string", "EventType [ TEST ]", s);
    }
}

==> commons-configuration2_2.2.orig.tar.xz: commons-configuration2-2.2-src/src/test/java/org/apache/commons/configuration2/event/TestEventType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.configuration2.event;

import static org.junit.Assert.assertEquals;

import org.junit.Before;
import org.junit.Test;

/**
 * Test class for {@code EventType}.
 *
 * @version $Id: TestEventType.java 1790899 2017-04-10 21:56:46Z ggregory $
 */
public class TestEventType
{
    /** The event type to be tested. */
    private EventType<Event> eventType;

    @Before
    public void setUp() throws Exception
    {
        eventType = new EventType<>(null, "TEST");
    }

    /**
     * Tests the string representation.
     */
    @Test
    public void testToString()
    {
        String s = eventType.toString();
        assertEquals("Wrong string", "EventType [ TEST ]", s);
    }
}
